@@ -3,6 +3,7 @@ package nodebootstrap_test
 import (
 	"strings"
 
+	"github.com/aws/aws-sdk-go/aws"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/ginkgo/extensions/table"
 	. "github.com/onsi/gomega"
@@ -93,7 +94,8 @@ var _ = Describe("AmazonLinux2 User Data", func() {
 API_SERVER_URL=
 B64_CLUSTER_CA=
 NODE_LABELS=
-NODE_TAINTS=`,
+NODE_TAINTS=
+CONTAINER_RUNTIME=`,
 		}),
 		Entry("maxPods set", bootScriptEntry{
 			ng: &api.NodeGroup{
@@ -107,7 +109,8 @@ API_SERVER_URL=
 B64_CLUSTER_CA=
 NODE_LABELS=
 NODE_TAINTS=
-MAX_PODS=123`,
+MAX_PODS=123
+CONTAINER_RUNTIME=`,
 		}),
 		Entry("labels and taints set", bootScriptEntry{
 			ng: &api.NodeGroup{
@@ -129,7 +132,22 @@ MAX_PODS=123`,
 API_SERVER_URL=
 B64_CLUSTER_CA=
 NODE_LABELS=role=worker
-NODE_TAINTS=key1=value1:NoSchedule`,
+NODE_TAINTS=key1=value1:NoSchedule
+CONTAINER_RUNTIME=`,
+		}),
+		Entry("container runtime set", bootScriptEntry{
+			ng: &api.NodeGroup{
+				NodeGroupBase: &api.NodeGroupBase{
+					SSH: &api.NodeGroupSSH{},
+				},
+				ContainerRuntime: aws.String(api.ContainerRuntimeContainerD),
+			},
+			expectedUserData: `CLUSTER_NAME=userdata-test
+API_SERVER_URL=
+B64_CLUSTER_CA=
+NODE_LABELS=
+NODE_TAINTS=
+CONTAINER_RUNTIME=containerd`,
 		}),
 
 		Entry("non-default ServiceIPv4CIDR", bootScriptEntry{
@@ -149,7 +167,8 @@ API_SERVER_URL=
 B64_CLUSTER_CA=
 NODE_LABELS=
 NODE_TAINTS=
-CLUSTER_DNS=172.16.0.10`,
+CLUSTER_DNS=172.16.0.10
+CONTAINER_RUNTIME=`,
 		}),
 	)
 
@@ -174,7 +193,8 @@ CLUSTER_DNS=172.16.0.10`,
 API_SERVER_URL=
 B64_CLUSTER_CA=
 NODE_LABELS=
-NODE_TAINTS=`, "\n")))
+NODE_TAINTS=
+CONTAINER_RUNTIME=`, "\n")))
 			Expect(cloudCfg.WriteFiles[1].Permissions).To(Equal("0644"))
 		})
 
