@@ -11,13 +11,15 @@ import (
 
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
+
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/utils"
 
+	kubeletapi "k8s.io/kubelet/config/v1beta1"
+
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/cloudconfig"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/bindata"
 	"github.com/weaveworks/eksctl/pkg/nodebootstrap/legacy"
-	kubeletapi "k8s.io/kubelet/config/v1beta1"
 )
 
 //go:generate ${GOBIN}/go-bindata -pkg bindata -prefix assets -nometadata -o bindata/assets.go bindata/assets
@@ -182,6 +184,10 @@ func makeBootstrapEnv(clusterConfig *api.ClusterConfig, np api.NodePool) cloudco
 		variables["CLUSTER_DNS"] = unmanaged.ClusterDNS
 	}
 
+	if unmanaged, ok := np.(*api.NodeGroup); ok && ng.AMIFamily == api.NodeImageFamilyAmazonLinux2 {
+		variables["CONTAINER_RUNTIME"] = unmanaged.GetContainerRuntime()
+	}
+
 	return cloudconfig.File{
 		Path:    configDir + envFile,
 		Content: makeKeyValues(variables, "\n"),
